![koalified](https://raw.github.com/domaintools/koalified_python/develop/artwork/logo.png)
===================

[![PyPI version](https://badge.fury.io/py/koalified.svg)](http://badge.fury.io/py/koalified)
[![Build Status](https://travis-ci.org/domaintools/koalified_python.svg?branch=master)](https://travis-ci.org/timothycrosley/koalified)
[![Coverage Status](https://coveralls.io/repos/domaintools/koalified_python/badge.svg?branch=master&service=github)](https://coveralls.io/github/timothycrosley/koalified?branch=master)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://pypi.python.org/pypi/koalified/)
[![Join the chat at https://gitter.im/domaintools/koalified_python](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/timothycrosley/koalified?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

For when truth is a little fuzzy.

[![koalified Example](https://raw.github.com/domaintools/koalified_python/develop/artwork/example.gif)](https://github.com/domaintools/koalified_python/blob/develop/examples/example.py)


Installing koalified
===================

Installing koalified is as simple as:

```bash
pip3 install koalified --upgrade
```

Ideally, within a virtual environment.


Why koalified?
===================

Koalified was built to help solve the case where the source of data can't be fully trusted but needs to be stored.
It allows specifying what should be, what can be, and what must be, in one concise schema definition.

--------------------------------------------

Thanks and I hope you find koalified helpful!

~Timothy Crosley
